from fastapi import FastAPI
from app.routes.cart_routes import router as cart_router
from app.routes.user_routes import router as user_router
from app.routes.shop_routes import router as shop_router

from app.core.config import EnvConfig, EnvConfigField

from app.database.manager import DatabaseManager


config = EnvConfig()

config.add_field("mysql_user", EnvConfigField("MYSQL_USER", required=True))
config.add_field("mysql_database", EnvConfigField("MYSQL_DATABASE", required=True))
config.add_field("mysql_host", EnvConfigField("MYSQL_HOST", required=True))
config.add_field("mysql_port", EnvConfigField("MYSQL_PORT", default=3306, data_type=int, required=False))
config.add_field("mysql_password", EnvConfigField("MYSQL_PASSWORD", required=True))

config.load_config()


config2 = EnvConfig()


DatabaseManager(
    mysql_user=config["mysql_user"],
    mysql_password=config["mysql_password"],
    mysql_host=config["mysql_host"],
    mysql_port=config["mysql_port"],
    mysql_db_name=config["mysql_database"],
)


app = FastAPI(
    title="SWAG Shop",
    version="0.0.1"
)

app.include_router(user_router)
app.include_router(cart_router)
app.include_router(shop_router)


@app.get("/")
async def root():
    return {"message": "Hello World"}
